summaryrefslogtreecommitdiff
path: root/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java
diff options
context:
space:
mode:
Diffstat (limited to 'eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java')
-rw-r--r--eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java47
1 files changed, 41 insertions, 6 deletions
diff --git a/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java b/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java
index 82e4bd1e..850a60c3 100644
--- a/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java
+++ b/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/api/idp/ISPConfiguration.java
@@ -1,4 +1,28 @@
/*******************************************************************************
+ * Copyright 2017 Graz University of Technology
+ * EAAF-Core Components has been developed in a cooperation between EGIZ,
+ * A-SIT+, A-SIT, and Graz University of Technology.
+ *
+ * Licensed under the EUPL, Version 1.2 or - as soon they will be approved by
+ * the European Commission - subsequent versions of the EUPL (the "Licence");
+ * You may not use this work except in compliance with the Licence.
+ * You may obtain a copy of the Licence at:
+ * https://joinup.ec.europa.eu/news/understanding-eupl-v12
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the Licence is distributed on an "AS IS" basis,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the Licence for the specific language governing permissions and
+ * limitations under the Licence.
+ *
+ * This product combines work with different licenses. See the "NOTICE" text
+ * file for details on the various modules and licenses.
+ * The "NOTICE" text file is part of the distribution. Any derivative works
+ * that you distribute must include a readable copy of the "NOTICE" text file.
+ *******************************************************************************/
+/*******************************************************************************
+ *******************************************************************************/
+/*******************************************************************************
*******************************************************************************/
package at.gv.egiz.eaaf.core.api.idp;
@@ -109,15 +133,26 @@ public interface ISPConfiguration extends Serializable {
public List<String> getTargetsWithNoBaseIdTransferRestriction();
/**
* Get the minimum eIDAS LoA that is required by this service provider
*
- * {@link EAAFConstants.EIDAS_QAA_LOW}
- * {@link EAAFConstants.EIDAS_QAA_SUBSTANTIAL}
- * {@link EAAFConstants.EIDAS_QAA_HIGH}
+ * @return return List of eIDAS LoAs
+ */
+ public List<String> getRequiredLoA();
+
+ /**
+ * Get required matching mode for LoAs
+ * {@link EIDAS_LOA_MATCHING_MINIMUM}
+ * {@link EIDAS_LOA_MATCHING_EXACT}
*
- * @return return eIDAS LoA
+ * @return
*/
- public String getMinimumLevelOfAssurence();
+ public String getLoAMatchingMode();
+
/**
* Get the full area-identifier for this service provider to calculate the
@@ -109,15 +133,26 @@ public interface ISPConfiguration extends Serializable {
public List<String> getTargetsWithNoBaseIdTransferRestriction();
/**
- * Get the minimum eIDAS LoA that is required by this service provider
+ * Get the List eIDAS LoA that are required by this service provider
+ *
+ * {@link EAAFConstants.EIDAS_LOA_LOW}
+ * {@link EAAFConstants.EIDAS_LOA_SUBSTANTIAL}
+ * {@link EAAFConstants.EIDAS_LOA_HIGH}
+ * or any other non-notified LoA scheme
*